@@ -46,7 +46,7 @@ class HorseracelampListHandler(ClientBaseHandler):
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else f"create_date>'{TimeHelper.add_hours_by_format_time(hour=-1)}'"
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_base_model = OrderBaseModel(context=self)
-        horseracelamp_list = self.business_process_executed(order_base_model.get_horseracelamp_list(act_id, module_id, is_search_module, condition, params, page_size), ref_params={})
+        horseracelamp_list = self.business_process_executed(order_base_model.get_horseracelamp_list(app_id, act_id, module_id, is_search_module, condition, params, page_size), ref_params={})
         return self.response_json_success(horseracelamp_list)
 
 
@@ -260,13 +260,12 @@ class SubmitSkuHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = self.get_act_id()
         open_id = self.get_param("open_id")
         user_prize_id = int(self.get_param("user_prize_id"))
         sku_name = self.get_param("sku_name")
         sku_id = self.get_param("sku_id")
 
-        prize_roster_model = PrizeRosterModel(context=self)
+        prize_roster_model = PrizeRosterModel(sub_table=FrameBaseModel(context=self).get_business_sub_table("prize_roster_tb", {"app_id": app_id}), context=self)
         prize_roster = prize_roster_model.get_entity_by_id(user_prize_id)
         if not prize_roster or prize_roster.open_id != open_id or prize_roster.app_id != app_id:
             return self.response_json_error("no_user_prize", "对不起，找不到该奖品")
