@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2023-01-04 15:57:34
+@LastEditTime: 2023-02-06 13:43:27
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -446,7 +446,8 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                         act_info_model = ActInfoModel(context=self)
                         act_info_dict = act_info_model.get_cache_dict(order_by="id desc")
                         if act_info_dict:
-                            user_info_model = UserInfoModel(context=self)
+                            frame_base_model = FrameBaseModel(context=self)
+                            user_info_model = UserInfoModel(sub_table=frame_base_model.get_business_sub_table("user_info_tb", {"app_id": act_info_dict["app_id"]}), context=self)
                             user_info_dict = user_info_model.get_cache_dict("act_id=%s and open_id=%s", limit="1", order_by="id desc", params=[act_info_dict["id"],open_id])
                             if user_info_dict:
                                 tiktok_goods_id_list = []
