@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 17:00:55
-@LastEditTime: 2022-07-21 13:59:22
+@LastEditTime: 2022-10-17 13:56:08
 @LastEditors: HuangJianYi
 @Description: 基础模块
 """
@@ -116,7 +116,7 @@ class SendSmsHandler(ClientBaseHandler):
                     self.logger_error.error(f"发送短信失败。Unknown exception:{e}")
                 return self.response_json_error("error","发送失败")
 
- 
+
 
 
 class MarketingProgramListHandler(ClientBaseHandler):
@@ -179,9 +179,9 @@ class SaveCmsInfoHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveCmsInfoHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title=info_title)
         else:
-            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveCmsInfoHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=info_title)
 
         return self.response_json_success(invoke_result_data.data["new"].id)
 
