@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-30 15:46:34
-@LastEditTime: 2021-11-29 16:39:08
+@LastEditTime: 2022-07-14 10:08:14
 @LastEditors: HuangJianYi
 @Description: 投放模块
 """
@@ -14,13 +14,13 @@ from seven_cloudapp_frame.models.db_models.act.act_info_model import *
 from seven_cloudapp_frame.models.db_models.act.act_prize_model import *
 from seven_cloudapp_frame.models.db_models.launch.launch_goods_model import *
 from seven_cloudapp_frame.models.db_models.price.price_gear_model import *
+from seven_cloudapp_frame.models.db_models.launch.launch_plan_model import *
 
 
 class InitLaunchGoodsHandler(ClientBaseHandler):
     """
     :description: 初始化商品投放
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 初始化商品投放
@@ -32,15 +32,16 @@ class InitLaunchGoodsHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         source_types = self.get_param("source_types","1,2")
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        online_url = self.get_online_url(act_id, app_id, module_id)
+        app_base_model = AppBaseModel(context=self)
         launch_base_model = LaunchBaseModel(context=self)
+        online_url = app_base_model.get_online_url(act_id, app_id, module_id)
         invoke_result_data = launch_base_model.init_launch_goods(app_id, act_id, source_types, online_url)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -55,24 +56,26 @@ class ResetLaunchGoodsHandler(ClientBaseHandler):
     """
     :description: 重置商品投放 删除已投放的记录并将活动投放状态改为未投放
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 重置商品投放 删除已投放的记录并将活动投放状态改为未投放
         :param app_id：应用标识
         :param act_id：活动标识
+        :param close_goods_id：投放失败时关闭投放的商品ID  多个逗号,分隔
         :return 
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         
+        close_goods_id = self.get_param("close_goods_id")
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        ActInfoModel(context=self).update_table("is_launch=0", "app_id=%s and id=%s", params=[app_id, act_id])
-        ActBaseModel(context=self)._delete_act_info_dependency_key(app_id, act_id)
-        LaunchGoodsModel(context=self).del_entity("app_id=%s and id=%s", params=[app_id, act_id])
+        launch_base_model = LaunchBaseModel(context=self)
+        invoke_result_data = launch_base_model.reset_launch_goods(app_id, act_id, close_goods_id)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -94,17 +97,16 @@ class InitLaunchGoodsCallBackHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         close_goods_id = self.get_param("close_goods_id")
-        
+
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        ActInfoModel(context=self).update_table("is_launch=1", "id=%s", params=act_id)
-        ActBaseModel(context=self)._delete_act_info_dependency_key(app_id,act_id)
-        if close_goods_id != "":
-            close_goods_id_list = list(set(close_goods_id.split(",")))
-            LaunchGoodsModel(context=self).update_table("is_launch=0,launch_date=%s", "act_id=%s and "+ SevenHelper.get_condition_by_str_list("goods_id",close_goods_id_list), params=[SevenHelper.get_now_datetime(),act_id])
+        launch_base_model = LaunchBaseModel(context=self)
+        invoke_result_data = launch_base_model.init_launch_goods_callback(app_id, act_id, close_goods_id)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -116,18 +118,17 @@ class UpdateLaunchGoodsStatusHandler(ClientBaseHandler):
     """
     :description: 更改投放商品的状态
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 保存更改投放商品的状态
         :param app_id：应用标识
-        :param 活动标识
+        :param act_id：活动标识
         :param update_goods_id：更新商品ID（例：1）
         :return 
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         goods_id = self.get_param("update_goods_id")
 
         invoke_result_data = self.business_process_executing()
@@ -146,7 +147,6 @@ class LaunchGoodsListHandler(ClientBaseHandler):
     """
     :description: 投放商品列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 投放商品列表
@@ -158,9 +158,11 @@ class LaunchGoodsListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
+        goods_id = self.get_param("goods_id")
+        launch_status = self.get_param_int("launch_status", -1)
         access_token = self.get_access_token()
 
         invoke_result_data = self.business_process_executing()
@@ -168,7 +170,7 @@ class LaunchGoodsListHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         launch_base_model = LaunchBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = launch_base_model.get_launch_goods_list(app_id, act_id, page_size, page_index, access_token, app_key, app_secret)
+        invoke_result_data = launch_base_model.get_launch_goods_list(app_id, act_id, page_size, page_index, access_token, app_key, app_secret,goods_id,launch_status)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -182,7 +184,6 @@ class AsyncLaunchGoodsHandler(ClientBaseHandler):
     """
     :description: 同步投放商品（小程序投放-商品绑定/解绑）
     """
-    @filter_check_params("app_id,act_id")
     def get_async(self):
         """
         :description: 同步投放商品（小程序投放-商品绑定/解绑）
@@ -193,22 +194,118 @@ class AsyncLaunchGoodsHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         access_token = self.get_access_token()
-        
+
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        online_url = self.get_online_url(act_id, app_id, module_id)
+        app_base_model = AppBaseModel(context=self)
+        online_url = app_base_model.get_online_url(act_id, app_id, module_id)
         launch_base_model = LaunchBaseModel(context=self)
-        
+
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = launch_base_model.async_launch_goods(app_id, act_id, online_url, access_token, app_key, app_secret)
+        launch_plan_model = LaunchPlanModel(context=self)
+        launch_plan = launch_plan_model.get_entity("act_id=%s", order_by="id desc", params=[act_id])
+        if launch_plan:
+            invoke_result_data = launch_base_model.async_launch_goods(app_id, act_id, launch_plan.launch_url, access_token, app_key, app_secret)
+        else:
+            invoke_result_data = launch_base_model.async_launch_goods(app_id, act_id, online_url, access_token, app_key, app_secret)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success()
\ No newline at end of file
+        return self.response_json_success()
+
+
+class GetLaunchPlanStatusHandler(ClientBaseHandler):
+    """
+    :description: 获取投放计划状态
+    :param act_id：活动标识
+    :return 
+    :last_editors: HuangJianYi
+    """
+    def get_async(self):
+        act_id = self.get_param_int("act_id")
+        access_token = self.get_access_token()
+        app_key, app_secret = self.get_app_key_secret()
+        launch_base_model = LaunchBaseModel(context=self)
+        launch_status = launch_base_model.get_launch_plan_status(act_id, access_token, app_key, app_secret)
+        return self.response_json_success(launch_status)
+
+
+class AsyncLaunchGoodsStatusHandler(ClientBaseHandler):
+    """
+    :description: 同步投放商品（小程序投放-商品绑定）
+    :return
+    :last_editors: HuangJianYi
+    """
+    def get_async(self):
+        act_id = self.get_act_id()
+        redis_init = SevenHelper.redis_init()
+        redis_init.rpush("queue_async_lauch", act_id)
+        return self.response_json_success()
+
+
+class AddLaunchGoodsHandler(ClientBaseHandler):
+    """
+    :description: 添加投放商品
+    :param goods_ids：商品id串 逗号分隔
+    :return
+    :last_editors: HuangJianYi
+    """
+    def get_async(self):
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
+        goods_ids = self.get_param("goods_ids")
+        launch_base_model = LaunchBaseModel(context=self)
+        launch_base_model.add_launch_goods_v2(app_id, act_id, goods_ids)
+        return self.response_json_success()
+
+
+class CanLaunchGoodsListHandler(ClientBaseHandler):
+    """
+    :description: 获取可投放商品列表（获取当前会话用户出售中的商品列表）
+    """
+    def get_async(self):
+        """
+        :description: 导入商品列表（获取当前会话用户出售中的商品列表）
+        :param goods_name：商品名称
+        :param order_tag：order_tag
+        :param order_by：排序类型
+        :param page_index：页索引
+        :param page_size：页大小
+        :return: 列表
+        :last_editors: HuangJianYi
+        """
+        access_token = self.get_access_token()
+        goods_name = self.get_param("goods_name")
+        order_tag = self.get_param("order_tag", "list_time")
+        order_by = self.get_param("order_by", "desc")
+        page_index = int(self.get_param("page_index", 0))
+        page_size = self.get_param("page_size", 20)
+        is_log = int(self.get_param("is_log", 0))
+        is_log = True if is_log == 1 else False
+        
+        access_token = self.get_access_token()
+        app_key, app_secret = self.get_app_key_secret()
+        launch_base_model = LaunchBaseModel(context=self)
+        invoke_result_data = launch_base_model.can_launch_goods_list(page_index,page_size,goods_name,order_tag,order_by,access_token,app_key,app_secret,is_log)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        return self.response_json_success(invoke_result_data.data)
+
+
+class GetLaunchProgressHandler(ClientBaseHandler):
+    """
+    :description: 获取投放进度
+    :return 投放进度 0未完成  1：已完成
+    :last_editors: HuangJianYi
+    """
+    def get_async(self):
+        act_id = self.get_act_id()
+        launch_base_model = LaunchBaseModel(context=self)
+        return self.response_json_success(launch_base_model.get_launch_progress(act_id))
\ No newline at end of file
