@@ -450,7 +450,7 @@ class SevenHelper:
         sub_table = None
         if not sub_count or not object_id:
             return sub_table
-        sub_table = str(object_id % sub_count)
+        sub_table = str(int(object_id) % sub_count)
         return sub_table
 
     @classmethod
