@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-11-30 09:35:31
+@LastEditTime: 2022-12-08 20:50:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -181,7 +181,7 @@ class WeChatHelper:
     def get_share_sign_package(self, request_url, app_id=""):
         """
         :description:获取分享请求参数
-        :param request_url:请求地址
+        :param request_url:请求地址 如果是服务端获取地址则使用 request_url = self.request.headers['Referer']
         :param app_id:app_id
         :return: 返回分享请求参数
         :last_editors: HuangJianYi
