@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2023-01-04 16:20:23
+@LastEditTime: 2023-02-06 14:34:55
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -187,8 +187,9 @@ class AssetBaseModel():
                 
                 return invoke_result_data
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
-        user_asset_model = UserAssetModel(db_transaction=db_transaction, context=self.context)
-        asset_log_model = AssetLogModel(db_transaction=db_transaction, context=self.context)
+        frame_base_model = FrameBaseModel(context=self.context)
+        user_asset_model = UserAssetModel(sub_table=frame_base_model.get_business_sub_table("user_asset_tb",{"app_id":app_id}),db_transaction=db_transaction, context=self.context)
+        asset_log_model = AssetLogModel(sub_table=frame_base_model.get_business_sub_table("asset_log_tb",{"app_id":app_id}),db_transaction=db_transaction, context=self.context)
         asset_only_model = AssetOnlyModel(db_transaction=db_transaction, context=self.context)
 
         acquire_lock_name = f"userasset:{user_asset_id_md5}"
@@ -370,7 +371,7 @@ class AssetBaseModel():
             else:
                 condition += " AND user_id=%s"
                 params.append(user_ids)
-        user_asset_model = UserAssetModel(context=self.context)
+        user_asset_model = UserAssetModel(sub_table=FrameBaseModel(context=self.context).get_business_sub_table("user_asset_tb",{"app_id":app_id}),context=self.context)
         user_asset_dict_list = user_asset_model.get_dict_list(condition, params=params)
         if len(user_asset_dict_list) > 0:
             for user_asset_dict in user_asset_dict_list:
@@ -394,7 +395,7 @@ class AssetBaseModel():
         """
         if not act_id or not user_id or not asset_type:
             return None
-        user_asset_model = UserAssetModel(context=self.context)
+        user_asset_model = UserAssetModel(sub_table=FrameBaseModel(context=self.context).get_business_sub_table("user_asset_tb",{"app_id":app_id}),context=self.context)
         user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
         user_asset_dict = user_asset_model.get_dict("id_md5=%s", limit="1", params=[user_asset_id_md5])
         if user_asset_dict:
@@ -472,7 +473,7 @@ class AssetBaseModel():
             else:
                 condition += " AND source_object_id=%s"
                 params.append(source_object_id)
-        asset_log_model = AssetLogModel(context=self.context)
+        asset_log_model = AssetLogModel(FrameBaseModel(context=self.context).get_business_sub_table("asset_log_tb",{"app_id":app_id}),context=self.context)
         if is_cache:
             page_list = asset_log_model.get_cache_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params, dependency_key=DependencyKey.asset_log_list(act_id,user_id), page_count_mode=page_count_mode)
         else:
@@ -518,7 +519,7 @@ class AssetBaseModel():
         :last_editors: HuangJianYi
         """
         asset_value = int(asset_value)
-        asset_log_model = AssetLogModel(context=self.context)
+        asset_log_model = AssetLogModel(sub_table=FrameBaseModel(context=self.context).get_business_sub_table("asset_log_tb",{"app_id":app_id}),context=self.context)
         asset_log = AssetLog()
         asset_log.app_id = app_id
         asset_log.act_id = act_id
