@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2022-12-19 09:46:51
+@LastEditTime: 2023-02-01 15:42:13
 @LastEditors: HuangJianYi
 :Description: 数据缓存业务模型
 """
@@ -17,7 +17,7 @@ class CacheModel(BaseModel):
 
     def __init__(self, model_class, sub_table):
         """
-        :Description: 数据缓存业务模型,用于mysql数据同步到redis，dependency_cache_expire(依赖建缓存时间默认300分钟，普通缓存默认30分钟)
+        :Description: 数据缓存业务模型,用于mysql数据同步到redis，dependency_cache_expire(依赖建缓存时间默认300分钟，普通缓存默认30分钟),查询结果是None和0不会被缓存，除非配置文件设置is_cache_empty=True
         :param model_class: 实体对象类
         :param sub_table: 分表标识
         :last_editors: HuangJianYi
