@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2022-11-15 15:02:38
+@LastEditTime: 2023-02-06 15:29:13
 @LastEditors: HuangJianYi
 @Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
 """
@@ -59,6 +59,7 @@ class ErpConsoleModel():
             try:
                 time.sleep(0.1)
                 erp_relation_model = ErpRelationModel()
+                frame_base_model = FrameBaseModel()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
@@ -68,7 +69,9 @@ class ErpConsoleModel():
                     for erp_relation_dict in erp_relation_list:
                         try:
                             erp_relation_model.update_table("sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), erp_relation_dict["id"]])
-                            prize_order_model = PrizeOrderModel()
+                            prize_order_model = PrizeOrderModel(sub_table=frame_base_model.get_business_sub_table("prize_order_tb", {"app_id": erp_relation_dict["app_id"]}))
+                            if not prize_roster_sub_table:
+                                prize_roster_sub_table = frame_base_model.get_business_sub_table("prize_roster_tb", {"app_id": erp_relation_dict["app_id"]})
                             prize_roster_model = PrizeRosterModel(sub_table=prize_roster_sub_table)
                             condition = "app_id=%s and order_status=0 and sync_status=0"
                             params = [erp_relation_dict["app_id"]]
@@ -190,8 +193,7 @@ class ErpConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
-                prize_order_model = PrizeOrderModel()
-                prize_roster_model = PrizeRosterModel()
+                frame_base_model = FrameBaseModel()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
                     erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
@@ -200,6 +202,8 @@ class ErpConsoleModel():
                 if len(erp_relation_list) > 0:
                     for erp_relation_dict in erp_relation_list:
                         try:
+                            prize_order_model = PrizeOrderModel(sub_table=frame_base_model.get_business_sub_table("prize_order_tb", {"app_id": erp_relation_dict["app_id"]}))
+                            prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"app_id": erp_relation_dict["app_id"]}))
                             erp_relation_model.update_table("return_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), erp_relation_dict["id"]])
                             if process_type == 1:
                                 key = "order_" + project_name + "_" + erp_relation_dict["app_id"]
