@@ -2,14 +2,14 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-12-13 10:38:22
+@LastEditTime: 2023-02-06 15:35:29
 @LastEditors: HuangJianYi
 @Description: 
 """
 import threading, multiprocessing
 from seven_framework.console.base_console import *
 from seven_cloudapp_frame.models.seven_model import InvokeResultData
-from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
+from seven_cloudapp_frame.models.frame_base_model import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.console_models.timing_work_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_queue_model import *
@@ -94,8 +94,7 @@ class StatConsoleModel():
                             create_day_int = int(create_date.strftime('%Y%m%d'))
                             create_month_int = int(create_date.strftime('%Y%m'))
                             create_year_int = int(create_date.strftime('%Y'))
-                            stat_config = config.get_value("stat_config", {})
-                            stat_log_model = StatLogModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(stat_orm.id, stat_config.get("statlog_subtable_num", 0)))
+                            stat_log_model = StatLogModel(sub_table=FrameBaseModel().get_business_sub_table("stat_log_tb", {"app_id": stat_queue.app_id}), db_transaction=db_transaction)
                             is_add = True
                             if stat_orm.repeat_type > 0:
                                 if stat_orm.repeat_type == 2:
@@ -189,8 +188,7 @@ class StatConsoleModel():
                     create_day_int = int(create_date.strftime('%Y%m%d'))
                     create_month_int = int(create_date.strftime('%Y%m'))
                     create_year_int = int(create_date.strftime('%Y'))
-                    stat_config = config.get_value("stat_config", {})
-                    stat_log_model = StatLogModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(stat_orm.id, stat_config.get("statlog_subtable_num", 0)))
+                    stat_log_model = StatLogModel(sub_table=FrameBaseModel().get_business_sub_table("stat_log_tb", {"app_id": stat_queue_dict["app_id"]}), db_transaction=db_transaction)
                     is_add = True
                     if stat_orm.repeat_type > 0:
                         if stat_orm.repeat_type == 2:
@@ -349,7 +347,7 @@ class ClearDataWork(TimingWork):
         stat_orm_model = StatOrmModel()
         page_index = 0
         while True:
-            stat_orm_dict_list, total = stat_orm_model.get_dict_page_list(field="id,repeat_type", page_index=page_index, page_size=50, order_by="id asc")
+            stat_orm_dict_list, is_next = stat_orm_model.get_dict_page_list(field="id,repeat_type", page_index=page_index, page_size=50, order_by="id asc", page_count_mode="next")
             if len(stat_orm_dict_list) <= 0:
                 break
             for stat_orm_dict in stat_orm_dict_list:
