@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2022-07-22 14:22:19
+@LastEditTime: 2022-09-06 14:03:27
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -31,6 +31,7 @@ class PrizeOrder:
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
         self.module_id = 0  # 活动模块标识
+        self.source_type = 1  # 来源类型（1用户下单2系统自动下单3商家操作下单业务自定义从101开始）
         self.user_id = 0  # 用户标识
         self.open_id = ""  # open_id
         self.user_nick = ""  # 用户昵称
@@ -75,7 +76,7 @@ class PrizeOrder:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'order_no', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'user_nick', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'address', 'deliver_date', 'express_no', 'express_company', 'order_status', 'buyer_remark', 'seller_remark', 'cs_modify_address', 'order_price', 'is_free_freight', 'freight_price', 'freight_pay_order_no', 'create_date', 'create_month', 'create_day', 'modify_date', 'sync_status', 'sync_date', 'sync_count', 'sync_result', 'i1', 'i2', 'i3', 'i4', 'i5', 's1','s2', 's3', 's4', 's5', 'd1', 'd2']
+        return ['id', 'order_no', 'app_id', 'act_id', 'module_id','source_type', 'user_id', 'open_id', 'user_nick', 'real_name', 'telephone', 'province', 'city', 'county', 'street', 'address', 'deliver_date', 'express_no', 'express_company', 'order_status', 'buyer_remark', 'seller_remark', 'cs_modify_address', 'order_price', 'is_free_freight', 'freight_price', 'freight_pay_order_no', 'create_date', 'create_month', 'create_day', 'modify_date', 'sync_status', 'sync_date', 'sync_count', 'sync_result', 'i1', 'i2', 'i3', 'i4', 'i5', 's1','s2', 's3', 's4', 's5', 'd1', 'd2']
 
     @classmethod
     def get_primary_key(self):
