@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2022-11-28 13:37:24
+@LastEditTime: 2023-02-06 11:49:58
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -152,27 +152,21 @@ class FrameBaseModel():
         else:
             return "交易成功"
 
-    def get_business_sub_table(self, key, param_dict):
+    def get_business_sub_table(self, table_name, param_dict):
         """
         :description: 获取分表名称
-        :param key:字典key
+        :param table_name:表名
         :param param_dict:参数字典
         :return:
         :last_editors: HuangJianYi
         """
-        if not param_dict or not key:
+        if not param_dict or not table_name:
             return None    
-        sub_table_config_list = config.get_value("sub_table_config_list",{})
-        sub_table_config = sub_table_config_list.get(key,{"sub_count":0,"sub_ways":0}) #sub_count分表数量，sub_ways分表方式（0-默认1-活动id取模2-用户id取模）
-        sub_ways = sub_table_config.get("sub_ways", 0)
-        if sub_ways == 1:
-            object_id = int(param_dict.get("act_id",0))
-        if sub_ways == 2:
-            object_id = int(param_dict.get("user_id",0))
-        else:
-            object_id = 0
-        
-        return SevenHelper.get_sub_table(object_id, sub_table_config.get("sub_count", 0))
+        sub_table_config = config.get_value("sub_table_config",{})
+        table_config = sub_table_config.get(table_name, None)
+        if not table_config:
+            return None
+        return SevenHelper.get_sub_table(param_dict.get("app_id", 0), table_config.get("sub_count", 10))
         
     def process_malice_request(self, handler_name, user_id, ip="", user_request_limit_num=30, ip_request_limit_num=30, cycle_type=1, limit_request_time=24):
         """
@@ -328,7 +322,7 @@ class FrameBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        user_info_model = UserInfoModel(context=self.context)
+        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}),context=self.context)
         id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
         user_info_dict = user_info_model.get_cache_dict("id_md5=%s", limit="1", params=[id_md5], dependency_key=DependencyKey.user_info(act_id,id_md5))
         if not user_info_dict:
