@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2023-01-30 17:29:37
+@LastEditTime: 2023-02-06 15:26:37
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -122,7 +122,7 @@ class OrderBaseModel(FrameBaseModel):
         if create_date_end:
             where += " AND create_date<=%s"
             params_list.append(create_date_end)
-        prize_order_model = PrizeOrderModel(context=self.context)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb",{"app_id":app_id}),context=self.context)
         if is_cache:
             page_list = prize_order_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, dependency_key=DependencyKey.prize_order_list(act_id,user_id), page_count_mode=page_count_mode)
         else:
@@ -132,7 +132,9 @@ class OrderBaseModel(FrameBaseModel):
             result = page_list[1]
             page_list = page_list[0]
         if is_search_roster == True:
-            prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table)
+            if not prize_roster_sub_table:
+                prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb",{"app_id":app_id})
+            prize_roster_model = PrizeRosterModel(sub_table=prize_roster_sub_table, context=self.context)
             if page_list and len(page_list)>0:
                 order_no_list = [str(i['order_no']) for i in page_list]
                 prize_roster_list_dict = prize_roster_model.get_dict_list(SevenHelper.get_condition_by_str_list("order_no",order_no_list))
@@ -158,8 +160,10 @@ class OrderBaseModel(FrameBaseModel):
         """
         now_datetime = SevenHelper.get_now_datetime()
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
-        prize_order_model = PrizeOrderModel(context=self.context, db_transaction=db_transaction)
-        prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table, db_transaction=db_transaction)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb",{"app_id":app_id}), db_transaction=db_transaction, context=self.context)
+        if not prize_roster_sub_table:
+            prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb",{"app_id":app_id})
+        prize_roster_model = PrizeRosterModel(sub_table=prize_roster_sub_table, db_transaction=db_transaction, context=self.context)
         invoke_result_data = InvokeResultData()
 
         prize_order = prize_order_model.get_entity_by_id(prize_order_id)
@@ -224,7 +228,7 @@ class OrderBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         now_datetime = SevenHelper.get_now_datetime()
-        prize_order_model = PrizeOrderModel(context=self.context)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb",{"app_id":app_id}),context=self.context)
         invoke_result_data = InvokeResultData()
 
         prize_order = prize_order_model.get_entity_by_id(prize_order_id)
@@ -265,7 +269,7 @@ class OrderBaseModel(FrameBaseModel):
         """
 
         now_datetime = SevenHelper.get_now_datetime()
-        prize_order_model = PrizeOrderModel(context=self.context)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb",{"app_id":app_id}),context=self.context)
         invoke_result_data = InvokeResultData()
 
         prize_order = prize_order_model.get_entity_by_id(prize_order_id)
@@ -319,8 +323,10 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="无效活动,无法导入订单"
             return invoke_result_data
-        prize_order_model = PrizeOrderModel(context=self.context)
-        prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb",{"app_id":app_id}),context=self.context)
+        if not prize_roster_sub_table:
+            prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb",{"app_id":app_id})
+        prize_roster_model = PrizeRosterModel(sub_table=prize_roster_sub_table, context=self.context)
         data = []
         total_num = 0
         if content_type == 1:
@@ -415,9 +421,9 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_message ="无效活动,无法创建订单"
             return invoke_result_data
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
-        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self.context)
-        prize_roster_model = PrizeRosterModel(db_transaction=db_transaction, context=self.context)
-        prize_order_model = PrizeOrderModel(db_transaction=db_transaction, context=self.context)
+        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}), db_transaction=db_transaction, context=self.context)
+        prize_roster_model = PrizeRosterModel(self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}), db_transaction=db_transaction, context=self.context)
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb",{"app_id":app_id}),db_transaction=db_transaction, context=self.context)
         prize_ids_list = []
         if prize_ids:
             prize_ids_list = prize_ids.split(',')
@@ -468,7 +474,6 @@ class OrderBaseModel(FrameBaseModel):
         else:
             prize_roster_list = prize_roster_model.get_list("act_id=%s and prize_status=0",params=[act_id])
 
-        prize_order_model = PrizeOrderModel(context=self.context)
         now_date = SevenHelper.get_now_datetime()
         prize_order = PrizeOrder()
         prize_order.app_id = app_id
@@ -854,16 +859,17 @@ class OrderBaseModel(FrameBaseModel):
             where += " AND create_date<=%s"
             params_list.append(create_date_end)
 
-        prize_roster_model = PrizeRosterModel(context=self.context)
+        prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}),context=self.context)
         if is_cache:
             page_list = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, dependency_key=DependencyKey.prize_roster_list(act_id,user_id), page_count_mode=page_count_mode)
         else:
             page_list = prize_roster_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, page_count_mode)
         return page_list
 
-    def get_horseracelamp_list(self, act_id, module_id, is_search_module=False, condition="", params=[], page_size=30):
+    def get_horseracelamp_list(self, app_id, act_id, module_id, is_search_module=False, condition="", params=[], page_size=30):
         """
         :description: 获取跑马灯奖品列表
+        :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
         :param is_search_module:是否查询活动模块
@@ -891,7 +897,7 @@ class OrderBaseModel(FrameBaseModel):
             if len(prize_id_list) > 0:
                 prize_ids = ",".join(prize_id_list)
                 condition_where.add_condition("prize_id in (" + prize_ids + ")")
-        prize_roster_model = PrizeRosterModel(context=self.context)
+        prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}),context=self.context)
         prize_roster_list = prize_roster_model.get_cache_dict_list(condition_where.to_string(), "", "create_date desc", str(page_size), "user_nick,prize_name,tag_id,module_name", params_list, cache_expire=60)
         total = int(len(prize_roster_list))
         if total == 0:
@@ -926,7 +932,7 @@ class OrderBaseModel(FrameBaseModel):
             false_act_prize_list = act_prize_model.get_cache_list(prize_condition, order_by="probability desc,chance desc", limit="30", params=prize_params,cache_expire=60)
             if len(false_act_prize_list) > 0 and add_num > 0:
                 now_datetime = TimeHelper.add_hours_by_format_time(hour=-random.randint(0, 1000))
-                user_info_list_dict = UserInfoModel(context=self.context).get_dict_list("act_id<%s and create_date>%s", params=[act_id,now_datetime], limit=str(add_num))
+                user_info_list_dict = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":false_act_prize_list[0].app_id}),context=self.context).get_dict_list("act_id<%s and create_date>%s", params=[act_id,now_datetime], limit=str(add_num))
 
                 for i in range(len(user_info_list_dict)):
                     false_act_prize = false_act_prize_list[random.randint(0, len(false_act_prize_list)-1)]
@@ -977,7 +983,7 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_message ="未授权请联系客服授权"
             return invoke_result_data
         dependency_key = f"prize_roster_list:actid_{act_id}_userid_{user_id}"
-        prize_roster_model = PrizeRosterModel(context=self.context)
+        prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}),context=self.context)
         prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=dependency_key)
         if not prize_roster_dict or prize_roster_dict['user_id'] != user_id or prize_roster_dict['act_id'] != act_id:
             invoke_result_data.success = False
