@@ -29,8 +29,8 @@ class StatBaseModel(FrameBaseModel):
         :param app_id：应用标识
         :param act_id：活动标识
         :param module_id：活动模块标识
-        :param user_id：用户标识
-        :param open_id：open_id
+        :param user_id：用户标识(比传)
+        :param open_id：open_id(可不传)
         :param key_name：统计key
         :param key_value：统计value
         :return:
@@ -65,8 +65,8 @@ class StatBaseModel(FrameBaseModel):
         :param app_id：应用标识
         :param act_id：活动标识
         :param module_id：活动模块标识
-        :param user_id：用户标识
-        :param open_id：open_id
+        :param user_id：用户标识(比传)
+        :param open_id：open_id(可不传)
         :param stat_data:统计数据
         :return:
         :last_editors: HuangJianYi
