@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2022-10-13 12:39:02
+@LastEditTime: 2022-12-19 10:17:38
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -1096,7 +1096,7 @@ class TopBaseModel():
         """
         :description: 获取淘宝会员信息
         :param mix_nick:mix_nick
-        :param nick:nick
+        :param nick:nick（淘宝废弃使用）
         :param access_token:access_token
         :param app_key:app_key
         :param app_secret:app_secret
@@ -1144,7 +1144,7 @@ class TopBaseModel():
         """
         :description: 实时查询当前是否店铺会员
         :param mix_nick:mix_nick
-        :param nick:nick
+        :param nick:nick（淘宝废弃使用）
         :param access_token:access_token
         :param app_key:app_key
         :param app_secret:app_secret
